pub enum NylError {
Show 18 variants
Template(Error),
HelmChart(String),
Config(String),
ApiResourceNotFound(String),
ConfigNotFound(String),
Io(Error),
Yaml(Error),
YamlCompat(Error),
YamlEmit(Error),
Json(Error),
Kubernetes(String),
Kubeconfig(KubeconfigError),
InferConfig(InferConfigError),
Process(String),
Validation(String),
ResourceValidation {
file: String,
message: String,
hint: String,
},
Git(GitError),
Other(String),
}Expand description
Main error type for nyl
Variants
Template(Error)
HelmChart(String)
Config(String)
ApiResourceNotFound(String)
ConfigNotFound(String)
Io(Error)
Yaml(Error)
YamlCompat(Error)
YamlEmit(Error)
Json(Error)
Kubernetes(String)
Kubeconfig(KubeconfigError)
InferConfig(InferConfigError)
Process(String)
Validation(String)
ResourceValidation
Git(GitError)
Other(String)
Implementations
Sourceimpl NylError
impl NylError
Sourcepub fn helm_chart(msg: impl Into<String>) -> Self
pub fn helm_chart(msg: impl Into<String>) -> Self
Create a Helm chart error with context
Sourcepub fn validation(msg: impl Into<String>) -> Self
pub fn validation(msg: impl Into<String>) -> Self
Create a validation error with context
Sourcepub fn kubernetes(msg: impl Into<String>) -> Self
pub fn kubernetes(msg: impl Into<String>) -> Self
Create a Kubernetes error with context
Sourcepub fn resource_validation(
file: impl Into<String>,
message: impl Into<String>,
hint: impl Into<String>,
) -> Self
pub fn resource_validation( file: impl Into<String>, message: impl Into<String>, hint: impl Into<String>, ) -> Self
Create a resource validation error with file context
Sourcepub fn is_config_error(&self) -> bool
pub fn is_config_error(&self) -> bool
Returns true if this error is related to configuration
Sourcepub fn is_kubernetes_error(&self) -> bool
pub fn is_kubernetes_error(&self) -> bool
Returns true if this error is related to Kubernetes operations
Sourcepub fn is_git_error(&self) -> bool
pub fn is_git_error(&self) -> bool
Returns true if this error is related to Git operations
Sourcepub fn is_api_resource_not_found_error(&self) -> bool
pub fn is_api_resource_not_found_error(&self) -> bool
Returns true if this is an API discovery miss for a specific GVK.